""" Miscellaneous manifest-building tests """

import logging
import sys
from pathlib import Path

# pylint: disable=E0401, E0402, R1721, W0611, W0621

import pytest

from ingest_envoy.ingestion_manifest import (
    IngestionManifest,
    IngestionManifestBuilder,
    find_manifest,
)
from ingest_envoy.manifest_components import (
    ARTIFACT_NAME,
    TARFILE_EXT,
)
from ingest_envoy.utilities import ScienceProductType, Telescope
from .conftest import ingest_path, populate_fake_evla_cal_ingest_path

logger = logging.getLogger(IngestionManifest.__name__)
logger.setLevel(logging.INFO)
logger.addHandler(logging.StreamHandler(sys.stdout))


def test_entry_point_for_evla_cal(ingest_path: Path):
    """
    Confirm that the ingestion launcher entrypoint kicks off production of ingestion manifest

    :param ingest_path: fake tmp ingestion path
    :return:
    """
    locator = "uid://evla/calibration/but-we-had-this-for-lunch-yesterday"
    populate_fake_evla_cal_ingest_path(ingest_path)
    sp_tar = [file for file in ingest_path.iterdir() if file.name.endswith(".tar")][0]
    assert sp_tar

    builder = IngestionManifestBuilder(
        telescope=Telescope.EVLA.value,
        locator=locator,
        sp_type=ScienceProductType.EVLA_CAL.value,
        staging_source_dir=ingest_path,
    )
    builder.build()
    ingestion_files = [file for file in ingest_path.iterdir()]

    # there should be one ingestion manifest....
    manifest_file = find_manifest(ingest_path)
    assert manifest_file

    # ...and an artifacts tar, and the science products tar we started with
    assert sp_tar in ingestion_files
    artifact_tars = [
        file
        for file in ingestion_files
        if file.name.startswith(ARTIFACT_NAME) and file.name.endswith(TARFILE_EXT)
    ]
    assert len(artifact_tars) == 1


@pytest.mark.skip("TODO: test_builds_realfast_sdm_manifest")
def test_builds_realfast_sdm_manifest():
    """
    Have we built a well-formed RealFast product ingestion manifest?

    :return:
    """
    raise NotImplementedError


@pytest.mark.skip("TODO: test_builds_vlass_quicklook_manifest")
def test_builds_vlass_quicklook_manifest():
    """
    Have we built a well-formed VLASS quicklook product ingestion manifest?

    :return:
    """
    raise NotImplementedError


@pytest.mark.skip("TODO: test_builds_gbt_manifest")
def test_builds_gbt_manifest():
    """
    Not yet in use, but sooner or later we'll need to create manifests
    for ingestion of GBT products.

    :return:
    """
    raise NotImplementedError


@pytest.mark.skip("TODO: test_builds_lvla_eb_manifest")
def test_builds_lvla_eb_manifest():
    """
    Not yet in use, but one of these days we'll need to create manifests
    for ingestion of LVLA execution blocks.

    :return:
    """
    raise NotImplementedError
